==> kdepim-addons-17.04.3.tar.xz: kdepim-addons-17.04.3/examples/apps/coisceim/coisceimpart.cpp <==
/*
    This file is part of Akonadi.

    Copyright (c) 2011 Stephen Kelly <steveire@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
    USA.
*/

#include "coisceimpart.h"

#include <QAction>
#include <kactioncollection.h>
#include <kstandardaction.h>

#include <kpluginfactory.h>

#include <QtCore/QFile>
#include <QtCore/QTextStream>
#include <QTimer>
#include <QTextEdit>
#include <QLabel>

K_PLUGIN_FACTORY(CoisceimPartFactory, registerPlugin<CoisceimPart>();)

CoisceimPart::CoisceimPart(QWidget *parentWidget, QObject *parent, const QVariantList & /*args*/)
    : KParts::ReadOnlyPart(parent)
{
    setComponentName(QStringLiteral("coisce"), QStringLiteral("coisce"));
    component = new CoisceimWidget(parentWidget);

    setWidget(component);
}

CoisceimPart::~CoisceimPart()
{
}
#include "coisceimpart.moc"

==> kdepim-addons-17.08.2.tar.xz: kdepim-addons-17.08.2/examples/apps/coisceim/coisceimpart.cpp <==
/*
    This file is part of Akonadi.

    Copyright (c) 2011 Stephen Kelly <steveire@gmail.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
    USA.
*/

#include "coisceimpart.h"

#include <QAction>
#include <kactioncollection.h>
#include <kstandardaction.h>

#include <kpluginfactory.h>

#include <QtCore/QFile>
#include <QtCore/QTextStream>
#include <QTimer>
#include <QTextEdit>
#include <QLabel>

K_PLUGIN_FACTORY(CoisceimPartFactory, registerPlugin<CoisceimPart>();
                 )

CoisceimPart::CoisceimPart(QWidget *parentWidget, QObject *parent, const QVariantList & /*args*/)
    : KParts::ReadOnlyPart(parent)
{
    setComponentName(QStringLiteral("coisce"), QStringLiteral("coisce"));
    component = new CoisceimWidget(parentWidget);

    setWidget(component);
}

CoisceimPart::~CoisceimPart()
{
}

#include "coisceimpart.moc"
